<?xml version="1.0" ?><!DOCTYPE TS><TS language="hr" version="2.1">
<context>
    <name>ExpressionBar</name>
    <message>
        <source>Expression Error</source>
        <translation>Neispravan izraz</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Dark theme</source>
        <translation>Tamna tema</translation>
    </message>
    <message>
        <source>Simple mode</source>
        <translation>Jednostavni način</translation>
    </message>
    <message>
        <source>Scientific mode</source>
        <translation>Znanstveni način</translation>
    </message>
    <message>
        <source>Deepin Calculator</source>
        <translation>Deepin kalkulator</translation>
    </message>
    <message>
        <source>Deepin Calculator is a simple and easy to use desktop calculator. It supports addition, subtraction, multiplication and division.</source>
        <translation>Deepin kalkulaator je jednostavan i lagan za korištenje. Podržava zbrajanje, oduzimanje,  množenje i dijeljenje.</translation>
    </message>
</context>
<context>
    <name>SimpleListDelegate</name>
    <message>
        <source>Expression Error</source>
        <translation>Neispravan izraz</translation>
    </message>
</context>
</TS>